# -*- coding: utf-8 -*-
#
# Copyright (c) 2019, HILSTER GmbH, Germany - https://hilster.io
# All rights reserved.
#

from __future__ import absolute_import, division, print_function
try:
    import hlm.core
except ImportError as e:
    print(e)
    pass

from hlm.__version__ import __version_info__, __version__


def hostid():
    """
    Build the unique host id used to identify a client for license unlocking.
    
    Returns:
        str: the hexlified host id
    """

    return hlm.core.get_hostid()


def add_used_license(product, version, license_name, license_header, license_entry):
    """
    Add a used license to the inventory. This method is thread safe.
    
    Args:
        license_data (dict): license data to be put into the used license data inventory.
    """
    return hlm.core.add_used_license(product, version, license_name, license_header, license_entry)


def get_used_licenses():
    """
    Get used licenses. This method is thread safe.
    
    Returns:
        dict: a deep copy of the used licenses inventory.
    """
    return hlm.core.get_used_licenses()


def get_used_licenses_formatted():
    """
    Get used licenses in a human readable way. This method is thread safe.
    
    Returns:
        list of str: the human readable information about the currently used licenses.
    """
    return hlm.core.get_used_licenses_formatted()


def get_used_licenses_formatted_html():
    licenses = get_used_licenses_formatted()

    ret = ""

    if len(licenses):
        ret = "<br/><br/>License information:<br/>\n"
        for lic in licenses:
            ret += lic + "<br/>\n"

    return ret


def add_license_path(path, pattern="*.txt"):
    """
    Add a license path that will be searched when unlocking products.
    
    Args:
        path (str): a path that will be searched for licenses matching ``pattern``
        pattern (str): a file pattern that may contain wildcard.
    """
    return hlm.core.add_license_path(path, pattern)


def add_license_module_path(module, pattern="*.txt"):
    """
    Add a license module path that will be searched when unlocking products.
    
    Args:
        module (str): an importable module path that will be searched for licenses matching ``pattern``
        pattern (str): a file pattern that may contain wildcard.
    """
    return hlm.core.add_license_module_path(module, pattern)


def get_extra_license_paths():
    """
    Get extra license paths added by the user.
    
    Returns:
        list of str: the list of license paths added by the user.
    """
    return hlm.core.get_extra_license_paths()


def activate_keys(server, activationkeys, output_directory=None, filename=None, insecure=False, raise_exceptions=True):
    """
    Activation procedure for multiple activation keys

    Args:
        server (string): the activation server url
        activationkeys (list of string): the activation keys to be used
        output_directory=None (str or None): if set the licenses is written into the output directory
        filename=None (str or None): if set store the licenses as ``filename``
        insecure=False (bool): if set to ``True`` ssl certificate verification is disables
        raise_exceptions=True (bool): if set to ``True`` an exception is raised in case of an error

    Returns:
        int: the number of failed activations

    """
    return hlm.core.activate_keys(
        server=server,
        activationkeys=activationkeys,
        output_directory=output_directory,
        filename=filename,
        insecure=insecure,
        raise_exceptions=raise_exceptions
    )


def activate_key(server, activationkey, output_directory=None, filename=None, insecure=False, raise_exceptions=True):
    """
    Activation procedure for a single activation key

    Args:
        server (str): the server url
        activationkey (str): the activation key to be used for activation
        output_directory=None (str or None): if set the licenses is written into the output directory
        filename=None (str or None): if set store the licenses as ``filename``
        insecure=False (bool): if set to ``True`` ssl certificate verification is disables
        raise_exceptions=True (bool): if set to ``True`` an exception is raised in case of an error

    Returns:
        int: ``0`` in case of a successful activation else ``1``.
    """
    return hlm.core.activate_key(
        server=server,
        activationkey=activationkey,
        output_directory=output_directory,
        filename=filename,
        insecure=insecure,
        raise_exceptions=raise_exceptions
    )


def renew(server, insecure=False):
    """
    Renew all activated licenses (with an activation key entry inside)

    Returns:
        int: the number of failed renewals
    """
    return hlm.core.renew(
        server=server,
        insecure=insecure
    )
